@@ -19,10 +19,10 @@ where
 {
     type Output = AddDataEndpoint<E, T>;
 
-    fn transform(self, ep: E) -> Self::Output {
+    fn transform(&self, ep: E) -> Self::Output {
         AddDataEndpoint {
             inner: ep,
-            value: self.value,
+            value: self.value.clone(),
         }
     }
 }
